@@ -4,6 +4,7 @@ use 5.026_000;
 use strict;
 use warnings;
 use utf8;
+use WebService::Hexonet::Connector::Logger;
 use WebService::Hexonet::Connector::Response;
 use WebService::Hexonet::Connector::ResponseTemplateManager;
 use WebService::Hexonet::Connector::SocketConfig;
@@ -19,7 +20,7 @@ Readonly my $IDX4                         => 4;
 Readonly our $ISPAPI_CONNECTION_URL       => 'https://api.ispapi.net/api/call.cgi';    # Default Connection Setup URL
 Readonly our $ISPAPI_CONNECTION_URL_PROXY => 'http://127.0.0.1/api/call.cgi';          # High Speed Connection Setup URL
 
-use version 0.9917; our $VERSION = version->declare('v2.8.0');
+use version 0.9917; our $VERSION = version->declare('v2.9.0');
 
 my $rtm = WebService::Hexonet::Connector::ResponseTemplateManager->getInstance();
 
@@ -31,10 +32,28 @@ sub new {
         debugMode    => 0,
         socketConfig => WebService::Hexonet::Connector::SocketConfig->new(),
         ua           => q{},
-        curlopts     => {}
+        curlopts     => {},
+        logger       => WebService::Hexonet::Connector::Logger->new()
     }, $class;
     $self->setURL($ISPAPI_CONNECTION_URL);
     $self->useLIVESystem();
+    $self->setDefaultLogger();
+    return $self;
+}
+
+
+sub setDefaultLogger {
+    my $self = shift;
+    $self->{logger} = WebService::Hexonet::Connector::Logger->new();
+    return $self;
+}
+
+
+sub setCustomLogger {
+    my ( $self, $logger ) = shift;
+    if ( defined($logger) && $logger->can('log') ) {
+        $self->{logger} = $logger;
+    }
     return $self;
 }
 
@@ -314,22 +333,17 @@ sub request {
 
     my $r = $ua->post( $cfg->{CONNECTION_URL}, $post );
     if ( $r->is_success ) {
-        $r = $r->decoded_content;
+        $r = WebService::Hexonet::Connector::Response->new( $r->decoded_content, $newcmd, $cfg );
         if ( $self->{debugMode} ) {
-            print {*STDOUT} Dumper($newcmd);
-            print {*STDOUT} Dumper($secured);
-            print {*STDOUT} Dumper($r);
+            $self->{logger}->log( $secured, $r );
         }
     } else {
-        my $err = $r->status_line;
-        $r = $rtm->getTemplate('httperror')->getPlain();
+        $r = WebService::Hexonet::Connector::Response->new( $rtm->getTemplate('httperror')->getPlain(), $newcmd, $cfg );
         if ( $self->{debugMode} ) {
-            print {*STDERR} Dumper($newcmd);
-            print {*STDERR} Dumper($secured);
-            print {*STDERR} Dumper($r);
+            $self->{logger}->log( $secured, $r, $r->status_line );
         }
     }
-    return WebService::Hexonet::Connector::Response->new( $r, $newcmd, $cfg );
+    return $r;
 }
 
 
@@ -588,10 +602,11 @@ Returns the current L<WebService::Hexonet::Connector::APIClient|WebService::Hexo
 Deactivates the debug mode. Debug mode is inactive by default.
 Returns the current L<WebService::Hexonet::Connector::APIClient|WebService::Hexonet::Connector::APIClient> instance in use for method chaining.
 
-=item C<getPOSTData( $command )>
+=item C<getPOSTData( $command, $secured )>
 
 Get POST data fields ready to use for HTTP communication based on LWP::UserAgent.
 Specify the API command for the request by $command.
+Specify if password data has to be replaced with asterix to secure it for output purposes by $secured. Optional.
 This method is internally used by the request method.
 Returns a hash.
 
